==> prestashop_1.4.0.14.zip: prestashop/modules/fianetfraud/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetfraud}prestashop>fianetfraud_740e53a0ed1b643f69c4aaa8ad4ae8d2'] = 'Codice corriere non valido';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7ccf58c950043c9fbfed668df13ce608'] = 'Impostazioni aggiornate';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_380b4179d36bce6ca862459a43b217b5'] = 'Per accedere, visitare:';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_592fcfe937f6d58f70d0918ef6373afa'] = 'Sito web Fia-net';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_f4f70727dc34561dfde1a3c529b6205c'] = 'Impostazioni';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b250a007769c7ffe655c74cfb8176b8c'] = 'ID sito';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_30dbd3dffa9dbd08b062436ba8dcbad7'] = 'Modalità di Produzione';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dbbd4d0ac4c725f3b0d2ff29abaf63'] = 'Tipo di prodotto per default';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7bc873cba11f035df692c3549366c722'] = '-- Scegli --';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5515d101ace462b70d5b5b5e55a8bfec'] = 'Dettagli categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_32b1e872d533aced68e8fd06117c35d9'] = 'Tipo di categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bb8d6a9f57dcf8f450d8c8b6107cfabb'] = 'Scegli una categoria ...';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5f001485711e47385cb84b10c888bbfd'] = 'Configurazione corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_84a4ee79ed85180a743340dceb2f98d1'] = 'Dettagli corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_914419aa32f04011357d3b604a86d7eb'] = 'Corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Tipo di corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Scegli un tipo di vettorecorriere...';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_803d8f90719db3a605cf4af72ab2d8ee'] = 'Tipo di corriere di default';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_4a04490d2817c00012562df7bc43299d'] = 'Configurazione pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_ff18b8d27988b97ba1dd72120dd524ea'] = 'Dettaglio di pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_ec51b543e5a38f6044c83f21dce2b23d'] = 'Modulo Pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7c9a3504dd4ce74b8021267ae1802968'] = 'Tipo di pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_127469a6b4253ebb77adccc0dd48461e'] = 'Sig.';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7f2a1b59ac1ab6d2d892dbbf4f132c40'] = 'Sig.ra';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Sconosciuto';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d13270d4831bb2a2723f0fb5b573807c'] = 'Convalida Fianet';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_e010021939a49b7cce07f0e546c1d54f'] = 'Vedi dettaglio';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_34f8a10ae57ac230a48fc44908bd40ad'] = 'Valutaz.';

==> prestashop_1.4.9.0.zip: prestashop/modules/fianetfraud/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetfraud}prestashop>fianetfraud_740e53a0ed1b643f69c4aaa8ad4ae8d2'] = 'Codice corriere non valido';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7ccf58c950043c9fbfed668df13ce608'] = 'Impostazioni aggiornate';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_39b34487212efb0589ecf8c774413d85'] = 'Il numero di telefono è richiesto';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_380b4179d36bce6ca862459a43b217b5'] = 'Per accedere, visitare:';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_592fcfe937f6d58f70d0918ef6373afa'] = 'Sito web Fia-net';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_f4f70727dc34561dfde1a3c529b6205c'] = 'Impostazioni';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b250a007769c7ffe655c74cfb8176b8c'] = 'ID sito';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_30dbd3dffa9dbd08b062436ba8dcbad7'] = 'Modalità di Produzione';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dbbd4d0ac4c725f3b0d2ff29abaf63'] = 'Tipo di prodotto per default';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7bc873cba11f035df692c3549366c722'] = '-- Scegli --';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5515d101ace462b70d5b5b5e55a8bfec'] = 'Dettagli categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_32b1e872d533aced68e8fd06117c35d9'] = 'Tipo di categoria';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bb8d6a9f57dcf8f450d8c8b6107cfabb'] = 'Scegli una categoria ...';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5f001485711e47385cb84b10c888bbfd'] = 'Configurazione corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_84a4ee79ed85180a743340dceb2f98d1'] = 'Dettagli corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_914419aa32f04011357d3b604a86d7eb'] = 'Corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Tipo di corriere';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Scegli un tipo di vettorecorriere...';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_803d8f90719db3a605cf4af72ab2d8ee'] = 'Tipo di corriere di default';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b41c57d638ef2d97b9231fb660dd136e'] = 'Configurazione pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_417f4dcb050401b8e65f19f152bc2781'] = 'Dettagli pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_521e389890dc5f0b41a83fa187eb3878'] = 'Modulo di pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_676b323eb96e2d3fa5b9afd415781b9a'] = 'Tipo di pagamento';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d8187ca1c7189a53c2ac6e8a7fe351d6'] = 'signore';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_43ee1d83b74b6407b7bf4160a5b28fd7'] = 'signora';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bf8fdb0995bc7db74f365551ffe9cf21'] = 'Signore';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_2b8713f4b603c6b9d9e8a10b6f4447d1'] = 'Signora';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Sconosciuto';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d13270d4831bb2a2723f0fb5b573807c'] = 'Convalida Fianet';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_e010021939a49b7cce07f0e546c1d54f'] = 'Vedi dettaglio';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_34f8a10ae57ac230a48fc44908bd40ad'] = 'Test';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_ec1b46ce1ea9dc8f509c9538f45b1de6'] = 'Dettagli';
